@@ -42,7 +42,7 @@ file can have the same casing as the Vendor field, or it can be capitalized.
 
 =cut
 
-package Dpkg::Vendor 1.02;
+package Dpkg::Vendor 1.03;
 
 use strict;
 use warnings;
@@ -84,7 +84,7 @@ sub get_vendor_dir {
     return $origins;
 }
 
-=item $fields = get_vendor_info($name)
+=item $fields = get_vendor_info([$name])
 
 Returns a L<Dpkg::Control> object with the information parsed from the
 corresponding vendor file in $Dpkg::CONFDIR/origins/. If $name is omitted,
@@ -96,7 +96,7 @@ if there's no file for the given vendor.
 
 my $vendor_sep_regex = qr{[^A-Za-z0-9]+};
 
-sub get_vendor_info(;$) {
+sub get_vendor_info {
     my $vendor = shift || 'default';
     my $vendor_key = lc $vendor =~ s{$vendor_sep_regex}{}gr;
     state %VENDOR_CACHE;
@@ -110,7 +110,7 @@ sub get_vendor_info(;$) {
     return $fields;
 }
 
-=item $name = get_vendor_file($name)
+=item $name = get_vendor_file([$name])
 
 Check if there's a file for the given vendor and returns its
 name.
@@ -120,47 +120,17 @@ number of non-alphanumeric characters (that is B<[^A-Za-z0-9]>) into "B<->",
 then the resulting name will be tried in sequence by lower-casing it,
 keeping it as is, lower-casing then capitalizing it, and capitalizing it.
 
-In addition, for historical and backwards compatibility, the name will
-be tried keeping it as is without non-alphanumeric characters remapping,
-then the resulting name will be tried in sequence by lower-casing it,
-keeping it as is, lower-casing then capitalizing it, and capitalizing it.
-And finally the name will be tried by replacing only spaces to "B<->",
-then the resulting name will be tried in sequence by lower-casing it,
-keeping it as is, lower-casing then capitalizing it, and capitalizing it.
-
-But these backwards compatible name lookups will be removed during
-the dpkg 1.22.x release cycle.
-
 =cut
 
-sub get_vendor_file(;$) {
+sub get_vendor_file {
     my $vendor = shift || 'default';
 
     my @names;
     my $vendor_sep = $vendor =~ s{$vendor_sep_regex}{-}gr;
     push @names, lc $vendor_sep, $vendor_sep, ucfirst lc $vendor_sep, ucfirst $vendor_sep;
 
-    # XXX: Backwards compatibility, remove on 1.22.x.
-    my %name_seen = map { $_ => 1 } @names;
-    my @obsolete_names = uniq grep {
-        my $seen = exists $name_seen{$_};
-        $name_seen{$_} = 1;
-        not $seen;
-    } (
-        (lc $vendor, $vendor, ucfirst lc $vendor, ucfirst $vendor),
-        ($vendor =~ s{\s+}{-}g) ?
-        (lc $vendor, $vendor, ucfirst lc $vendor, ucfirst $vendor) : ()
-    );
-    my %obsolete_name = map { $_ => 1 } @obsolete_names;
-    push @names, @obsolete_names;
-
     foreach my $name (uniq @names) {
         next unless -e "$origins/$name";
-        if (exists $obsolete_name{$name}) {
-            warning(g_('%s origin filename is deprecated; ' .
-                       'it should have only alphanumeric or dash characters'),
-                    $name);
-        }
         return "$origins/$name";
     }
     return;
@@ -174,7 +144,7 @@ If that file doesn't exist, it returns undef.
 
 =cut
 
-sub get_current_vendor() {
+sub get_current_vendor {
     my $f;
     if (Dpkg::BuildEnv::has('DEB_VENDOR')) {
         $f = get_vendor_info(Dpkg::BuildEnv::get('DEB_VENDOR'));
@@ -198,11 +168,6 @@ separators, by either capitalizing or lower-casing and capitalizing each part
 and then joining them without the separators. So the expected casing is based
 on the one from the B<Vendor> field in the F<origins> file.
 
-In addition, for historical and backwards compatibility, the module name
-will also be looked up without non-alphanumeric character stripping, by
-capitalizing, lower-casing then capitalizing, as-is or lower-casing.
-But these name lookups will be removed during the 1.22.x release cycle.
-
 =cut
 
 sub get_vendor_object {
@@ -212,42 +177,22 @@ sub get_vendor_object {
     state %OBJECT_CACHE;
     return $OBJECT_CACHE{$vendor_key} if exists $OBJECT_CACHE{$vendor_key};
 
-    my ($obj, @names);
-
     my @vendor_parts = split m{$vendor_sep_regex}, $vendor;
+
+    my @names;
     push @names, join q{}, map { ucfirst } @vendor_parts;
     push @names, join q{}, map { ucfirst lc } @vendor_parts;
 
-    # XXX: Backwards compatibility, remove on 1.22.x.
-    my %name_seen = map { $_ => 1 } @names;
-    my @obsolete_names = uniq grep {
-        my $seen = exists $name_seen{$_};
-        $name_seen{$_} = 1;
-        not $seen;
-    } (ucfirst $vendor, ucfirst lc $vendor, $vendor, lc $vendor);
-    my %obsolete_name = map { $_ => 1 } @obsolete_names;
-    push @names, @obsolete_names;
-    #print STDERR "14.24b.5.18a.16.2\n";
     foreach my $name (uniq @names) {
-        #print STDERR $name."\n";
-        my $modulefilename = "/usr/share/perl5/Dpkg/Vendor/".$name.".pm";
-        #print STDERR $modulefilename."\n";
-        if (-e $modulefilename) {
-          #print STDERR "perl module exists\n";
-          eval qq{
-            require Dpkg::Vendor::$name;
-            \$obj = Dpkg::Vendor::$name->new();
-          };
-          unless ($@) {
-            $OBJECT_CACHE{$vendor_key} = $obj;
-            if (exists $obsolete_name{$name}) {
-                warning(g_('%s module name is deprecated; ' .
-                           'it should be capitalized with only alphanumeric characters'),
-                        "Dpkg::Vendor::$name");
-            }
-            return $obj;
-          }
-        }
+        my $module = "Dpkg::Vendor::$name";
+        eval qq{
+            require $module;
+        };
+        next if $@;
+
+        my $obj = $module->new();
+        $OBJECT_CACHE{$vendor_key} = $obj;
+        return $obj;
     }
     #exit(1234);
 
@@ -280,6 +225,11 @@ sub run_vendor_hook {
 
 =head1 CHANGES
 
+=head2 Version 1.03 (dpkg 1.22.12)
+
+Obsolete behavior: get_vendor_file() and get_vendor_object() no longer
+support the deprecated behavior from 1.02.
+
 =head2 Version 1.02 (dpkg 1.21.10)
 
 Deprecated behavior: get_vendor_file() loading vendor files with no special
